# whatsappstract
exTRACTs stuff from WHATSAPP

# Install

```
pip install whatsappstract
```

# Run

Make sure you have the geckodriver executable in your PATH. Then, run:

```
python -m whatsappstract
```
